[svn commit] r435 - trunk/include/minor

jimb at red-bean.com jimb at red-bean.com
Fri Apr 22 02:30:14 CDT 2005


Author: jimb
Date: Fri Apr 22 02:30:13 2005
New Revision: 435

Modified:
   trunk/include/minor/unicode.h
Log:
Doc fixes.

Note need to revise error reporting of string conversion functions.


Modified: trunk/include/minor/unicode.h
==============================================================================
--- trunk/include/minor/unicode.h	(original)
+++ trunk/include/minor/unicode.h	Fri Apr 22 02:30:13 2005
@@ -80,6 +80,15 @@
 /* Conversions between Unicode and the C execution character set.  */
 
 
+/* The functions on this page are somewhat independent of the rest of
+   Minor.  But since Minor does use Unicode internally, it needs them
+   for its own uses anyway; and since it does export and import data
+   in Unicode, Minor clients will occasionally find them useful, too.
+
+   These functions don't operate on Scheme values, so they don't take
+   mn_call arguments or references.  They use custom conventions for
+   reporting errors, rather than setting the pending exception.  */
+
 /* Given a Unicode scalar value U, return the corresponding 'char' /
    'wchar_t' value in the current C execution character set.
 
@@ -101,6 +110,9 @@
 mn_unicode_int_t mn_wchar_to_unicode (wint_t c);
 
 
+... /* These should distinguish the error cases described in minor.h,
+       under "Characters".  */
+
 /* Given a string / wide string MEM in the current C execution
    character set, which is LEN bytes / wchar_t values long, return the
    corresponding string in UTF-8, set *RESULT_SIZE to its size in
@@ -140,14 +152,17 @@
 
 /* Functions for operating on UTF-8 text.  */
 
-/* These functions don't really have anything directly to do with
-   Scheme or Minor, but since Minor does use UTF-8 internally, it
-   needs them for its own uses anyway; and since it does export and
-   import data in UTF-8, Minor clients will occasionally find them
-   useful, too.  */
+/* The functions on this page are somewhat independent of the rest of
+   Minor.  But since Minor does use UTF-8 internally, it needs them
+   for its own uses anyway; and since it does export and import data
+   in UTF-8, Minor clients will occasionally find them useful, too.
+
+   These functions don't operate on Scheme values, so they don't take
+   mn_call arguments or references.  They use custom conventions for
+   reporting errors, rather than setting the pending exception.  */
 
-/* The maximum length of a character encoded in UTF-8, in code units
-   (bytes).  */
+/* The maximum length of a Unicode character encoded in UTF-8, in code
+   units (bytes).  */
 #define MN_UTF8_MAX_LEN (4)
 
 /* The largest code point that can be encoded in UTF-8.




More information about the Minor mailing list